@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.dataqna_v1alpha.types import auto_suggestion_service
 from .transports.base import AutoSuggestionServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import AutoSuggestionServiceGrpcTransport
@@ -407,7 +409,7 @@ class AutoSuggestionServiceClient(metaclass=AutoSuggestionServiceClientMeta):
         self,
         request: Union[auto_suggestion_service.SuggestQueriesRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> auto_suggestion_service.SuggestQueriesResponse:
